#ifndef LOGINPROMPT_H
#define LOGINPROMPT_H

#include <QWidget>
#include "appdownloader-comm/MaemoApplicationHandler.h"
#include "loadwidget.h"

namespace Ui {
    class LoginPrompt;
}

class LoginPrompt : public QWidget {
    Q_OBJECT
public:
    explicit LoginPrompt(MaemoApplicationHandler *,QWidget *parent = 0);
    ~LoginPrompt();

public slots:
    void loginResponse (int);

signals:
    void loggedIn (QString);

protected:
    void changeEvent(QEvent *e);
private slots:
    void userLogin ();


private:
    Ui::LoginPrompt *ui;
    MaemoApplicationHandler *applicationHandler;
    QString username;
    LoadWidget *loading;
};

#endif // LOGINPROMPT_H
